==> qsstv_8.2.12.orig.tar.gz: qsstv_8.2.12/qsstv/utils/loggingparams.cpp <==
/**************************************************************************
*   Copyright (C) 2000-2012 by Johan Maes                                 *
*   on4qz@telenet.be                                                      *
*   http://users.telenet.be/on4qz                                         *
*                                                                         *
*   This program is free software; you can redistribute it and/or modify  *
*   it under the terms of the GNU General Public License as published by  *
*   the Free Software Foundation; either version 2 of the License, or     *
*   (at your option) any later version.                                   *
*                                                                         *
*   This program is distributed in the hope that it will be useful,       *
*   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
*   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
*   GNU General Public License for more details.                          *
*                                                                         *
*   You should have received a copy of the GNU General Public License     *
*   along with this program; if not, write to the                         *
*   Free Software Foundation, Inc.,                                       *
*   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
***************************************************************************/
#include "loggingparams.h"

QString levelStr[NUMDEBUGLEVELS]=
{
  "GALLERY ",
  "PARAMS  ",
  "FFT     ",
  "WAVIO   ",
  "SYNTHES ",
  "DISPATC ",
  "SOUNDIO ",
  "RXFUNC  ",
  "TXFUNC  ",
  "SYNCPRC1",
  "SYNCPRC2",
  "SLANTAD ",
  "MODES   ",
  "FTP     ",
  "IMAGE   ",
  "SCOPE   ",
  "CAM     ",
  "RX MAIN ",
  "TX MAIN ",
  "EDITOR  ",
  "RIGCTRL ",
  "DRMDEMOD",
  "DRMRXSRC",
  "DRMMOT  ",
  "DRMTX   ",
  "DRMTXMOT",
  "DRMTXCOD",
  "DRMTXAAA",
  "XMLRPC  ",
  "PERFORM "
};

==> qsstv_9.0.7.tar.gz: qsstv_9.0.7/qsstv/utils/loggingparams.cpp <==
/**************************************************************************
*   Copyright (C) 2000-2012 by Johan Maes                                 *
*   on4qz@telenet.be                                                      *
*   http://users.telenet.be/on4qz                                         *
*                                                                         *
*   This program is free software; you can redistribute it and/or modify  *
*   it under the terms of the GNU General Public License as published by  *
*   the Free Software Foundation; either version 2 of the License, or     *
*   (at your option) any later version.                                   *
*                                                                         *
*   This program is distributed in the hope that it will be useful,       *
*   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
*   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
*   GNU General Public License for more details.                          *
*                                                                         *
*   You should have received a copy of the GNU General Public License     *
*   along with this program; if not, write to the                         *
*   Free Software Foundation, Inc.,                                       *
*   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
***************************************************************************/
#include "loggingparams.h"



QString levelStr[NUMDEBUGLEVELS]=
{
  "GALLERY  ",
  "PARAMS   ",
  "FFT      ",
  "WAVIO    ",
  "SYNTHES  ",
  "DISPATC  ",
  "SOUNDIO  ",
  "RXFUNC   ",
  "TXFUNC   ",
  "SYNCSTATE",
  "SYNCPROCESSSTATE",
  "SYNCEXTR ",
  "SYNCEVAL",
  "SYNCACC  ",
  "SYNCREJ  ",
  "SYNCMATCH",
  "SYNCLOST",
  "SLANTAD  ",
  "MODES    ",
  "FTP      ",
  "IMAGE    ",
  "SCOPE    ",
  "CAM      ",
  "RX MAIN  ",
  "TX MAIN  ",
  "EDITOR   ",
  "RIGCTRL  ",
  "DRMDEMOD ",
  "DRMRXSRC ",
  "DRMMOT   ",
  "DRMTX    ",
  "DRMTXMOT ",
  "DRMTXCOD ",
  "DRMTXAAA ",
  "XMLRPC   ",
  "FSKID    ",
  "VISCODE  ",
  "RETRACE  ",
  "CALIBRATE",
  "PERFORM  "
};
